@@ -1,11 +1,11 @@
 import cv2
 from .utils import Utils
 import tqdm
-import imageio
 import sys
 from typing import Optional
 from multiprocessing import Queue
 import math
+from .text_style import TextStyle
 
 
 class Reader:
@@ -15,17 +15,17 @@ class Reader:
         output: Optional[str] = None,
         width: Optional[int] = None,
         fps_reduction: int = 1,
-        quality: int = 100,
+        dither: bool = False,
         shit_optimize: bool = False,
         text: str = "",
-        text_style: str = "top",
+        text_style: TextStyle = TextStyle.TOP,
         progress_bar: bool = False
     ):
         self.filename = filename
         self.output = output
         self.width = width
         self.fps_reduction = fps_reduction
-        self.quality = quality
+        self.dither = dither
         self.shit_optimize = shit_optimize
         self.text = text
         self.text_style = text_style
@@ -60,8 +60,8 @@ class Reader:
                     frame, 
                     self.text_overlay_image, 
                     self.width, 
-                    self.text, 
-                    self.quality, 
+                    self.text,
+                    self.dither
                 )
 
                 self.frames.put(frame)
@@ -77,4 +77,4 @@ class Reader:
             sys.stdout.flush()
         cap.release()
 
-        return
\ No newline at end of file
+        return
